pub struct Config {
pub iroh: IrohConfig,
pub storage: StorageConfig,
pub rpc: RpcConfig,
}Fields
iroh: IrohConfigstorage: StorageConfigrpc: RpcConfigTrait Implementations
Sourceimpl AsRef<IrohConfig> for Config
impl AsRef<IrohConfig> for Config
Sourcefn as_ref(&self) -> &IrohConfig
fn as_ref(&self) -> &IrohConfig
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl AsRef<StorageConfig> for Config
impl AsRef<StorageConfig> for Config
Sourcefn as_ref(&self) -> &StorageConfig
fn as_ref(&self) -> &StorageConfig
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl From<Config> for PartialConfig
impl From<Config> for PartialConfig
Sourcefn from(value: Config) -> PartialConfig
fn from(value: Config) -> PartialConfig
Converts to this type from the input type.